
extern char * Inet_HostName(char *ip);
extern char * Inet_NameToIp(char *name);
extern char * Inet_MyIPAddress(void);
extern char * Inet_MyMACAddress(void);
extern char * Inet_MySubnet(void);

extern int Inet_HostInLAN(void);
extern SniffingHost * Inet_NoSniff(void);

extern void Inet_PutMACinString(char *mac_string, unsigned char *MAC);
extern int Inet_GetMACfromString(char *mac_string, unsigned char *MAC);
extern int Inet_CheckSwitch(void);

extern int Inet_Fake_Host(void);

// Following are architecture dependent !! implementations are in ./src/`uname`/ec_inet_`uname`.c

extern int Inet_FindIFace(char *iface);
extern char Inet_CorrectIface(char *iface);

extern int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, unsigned long *NetMask);
extern int Inet_SetPromisc(char *iface);

extern int Inet_OpenRawSock(char *iface);
extern int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type);
extern int Inet_SendRawPacket(int sock, char *buffer, int len);
extern int Inet_SetARPEntry(unsigned long IP, char MAC[6]);
extern void Inet_DisableForwarding(void);
extern void Inet_SetRoute(void);
extern char *Inet_MacFromIP(unsigned long ip);

/* EOF */
